@@ -23,8 +23,7 @@ def add_command(subp):
       "the regex matching is very powerful, "
       "be certain that you match what you think!")
   grade_parser.set_defaults(func=grade_command)
-  users.add_user_option(grade_parser, required=True)
-  submissions.add_submission_options(grade_parser)
+  submissions.add_submission_options(grade_parser, required=True)
   grade_options = grade_parser.add_argument_group(
     "arguments to set the grade and/or comment, "
     "if none given, opens SpeedGrader")
