@@ -50,14 +50,14 @@ def submission_command(config, canvas, args):
   submission_list = process_submission_options(canvas, args)
   for submission in submission_list:
     pydoc.pager(format_submission(submission))
-def add_submission_options(parser):
+def add_submission_options(parser, required=False):
   try:
-    assignments.add_assignment_option(parser)
+    assignments.add_assignment_option(parser, required=required)
   except argparse.ArgumentError:
     pass
 
   try:
-    users.add_user_or_group_option(parser)
+    users.add_user_or_group_option(parser, required=required)
   except argparse.ArgumentError:
     pass
 
